@@ -98,7 +98,7 @@ CVhybridEnsemble <- function(x=NULL,
                              AB.iter=500,
                              AB.maxdepth=3,
                              KF.cp=1,
-                             KF.rp=round(log(ncol(x)+1,4)),
+                             KF.rp=round(log(nrow(x),10)),
                              NN.rang=0.1,
                              NN.maxit=10000,
                              NN.size=c(5,10,20),
